TraciError

Enum TraciError 

pub enum TraciError {
    Connection(Error),
    Protocol(String),
    SimulationError(String),
    NotImplemented(String),
    SimulationEnd,
}
All errors that can be returned by the TraCI client.

Variants



Connection(Error)

A TCP/IP I/O error occurred (connect, send, receive, …).



Protocol(String)

The server responded with a protocol-level error (wrong command id, bad message length, unexpected type tag, …).



SimulationError(String)

The SUMO server returned RTYPE_ERR for a command we sent.



NotImplemented(String)

The SUMO server replied that the requested command is not implemented.



SimulationEnd

SUMO has reached the configured end time and closed the simulation. Returned by [TraciClient::simulation_step] when CMD_CLOSE is received.